# -*- coding: utf-8 -*-
pass
from chameleon.utils import Placeholder as _Placeholder
import sys as _sys
pass
_static_37141392 = {}
_static_37138960 = {}
_static_36743056 = {}
_marker_default = _Placeholder()
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    _backup_attrs_40147424 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x230a790> name=None at 230a490> -> _value
    _value = _static_36743056
    econtext['attrs'] = _value

    # <html ... (1:0)
    # --------------------------------------------------------
    append(u'<html>')
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    __fallback_34354496 = len(stream)
    try:
        _backup_attrs_40147568 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x236b210> name=None at 236b490> -> _value
        _value = _static_37138960
        econtext['attrs'] = _value

        # <body ... (2:2)
        # --------------------------------------------------------
        append(u'<body>')
        _content_139955154988272 = u'\n    '
        if (_content_139955154988272 is not None):
            append(_content_139955154988272)
        _backup_attrs_40167832 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x236bb90> name=None at 236b3d0> -> _value
        _value = _static_37141392
        econtext['attrs'] = _value

        # <div ... (3:4)
        # --------------------------------------------------------
        append(u'<div>')
        _backup_default_40145120 = get('default', _marker)

        # <Marker name='default' at 236b690> -> _value
        _value = _marker_default
        econtext['default'] = _value

        # <Expression u'undefined' (3:22)> -> _cache_37138512
        try:
            _cache_37138512 = getitem('undefined')
        except:
            rcontext.setdefault('__error__', []).append((u'undefined', 3, 22, '<string>', _sys.exc_info()[1], ))
            raise


        # <Identity expression=<Expression u'undefined' (3:22)> value=<Marker name='default' at 236b7d0> at 236bfd0> -> _condition
        _expression = _cache_37138512

        # <Marker name='default' at 236b7d0> -> _value
        _value = _marker_default
        _condition = (_expression is _value)
        if _condition:
            pass
        else:
            _content = _cache_37138512
            if (_content is None):
                pass
            else:
                if (_content is False):
                    _content = None
                else:
                    _tt = type(_content)
                    if ((_tt is int) or (_tt is float) or (_tt is long)):
                        _content = unicode(_content)
                    else:
                        try:
                            if (_tt is str):
                                _content = decode(_content)
                            else:
                                if (_tt is not unicode):
                                    try:
                                        _content = _content.__html__
                                    except:
                                        _content = convert(_content)
                                    else:
                                        raise RuntimeError
                        except RuntimeError:
                            _content = _content()
                        else:
                            if ((_content is not None) and (re_needs_escape(_content) is not None)):
                                if ('&' in _content):
                                    if (';' in _content):
                                        _content = re_amp.sub('&amp;', _content)
                                    else:
                                        _content = _content.replace('&', '&amp;')
                                if ('<' in _content):
                                    _content = _content.replace('<', '&lt;')
                                if ('>' in _content):
                                    _content = _content.replace('>', '&gt;')
                                if ('\x00' in _content):
                                    _content = _content.replace('\x00', '&#34;')
            if (_content is not None):
                append(_content)
        if (_backup_default_40145120 is _marker):
            del econtext['default']
        else:
            econtext['default'] = _backup_default_40145120
        append(u'</div>')
        if (_backup_attrs_40167832 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_40167832
        _content_139955154988272 = u'\n  '
        if (_content_139955154988272 is not None):
            append(_content_139955154988272)
        append(u'</body>')
        if (_backup_attrs_40147568 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_40147568
    except (NameError, ValueError, AttributeError, LookupError, TypeError, ):
        del stream[__fallback_34354496:]

        # <Expression u'string:error' (2:22)> -> _content
        try:
            _content = u'error'
        except:
            rcontext.setdefault('__error__', []).append((u'string:error', 2, 22, '<string>', _sys.exc_info()[1], ))
            raise

        if (_content is not None):
            _tt = type(_content)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _content = str(_content)
            else:
                if (_tt is str):
                    _content = decode(_content)
                else:
                    if (_tt is not unicode):
                        try:
                            _content = _content.__html__
                        except AttributeError:
                            _content = convert(_content)
                        else:
                            _content = _content()
        if (_content is not None):
            append(_content)

    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</html>')
    if (_backup_attrs_40147424 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_40147424
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
pass


# -*- coding: utf-8 -*-
pass
from chameleon.utils import Placeholder as _Placeholder
import sys as _sys
pass
_static_38579792 = {}
_static_38552272 = {}
_static_35801168 = {}
_static_38555600 = {}
_static_35799376 = {}
_static_38553168 = {}
_static_38553552 = {}
_marker_default = _Placeholder()
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    _backup_attrs_39070032 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24c4650> name=None at 223a290> -> _value
    _value = _static_38553168
    econtext['attrs'] = _value

    # <html ... (1:0)
    # --------------------------------------------------------
    append(u'<html>')
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_39067944 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24c4fd0> name=None at 24c4f90> -> _value
    _value = _static_38555600
    econtext['attrs'] = _value

    # <body ... (2:2)
    # --------------------------------------------------------
    append(u'<body>')
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_39069312 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24c47d0> name=None at 24c4b90> -> _value
    _value = _static_38553552
    econtext['attrs'] = _value

    # <div ... (3:4)
    # --------------------------------------------------------
    append(u'<div>')
    _backup_default_39069744 = get('default', _marker)

    # <Marker name='default' at 24c4610> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u'string:1 < 2' (3:27)> -> _cache_38555024
    try:
        _cache_38555024 = u'1 < 2'
    except:
        rcontext.setdefault('__error__', []).append((u'string:1 < 2', 3, 27, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u'string:1 < 2' (3:27)> value=<Marker name='default' at 24c4e10> at 24c4950> -> _condition
    _expression = _cache_38555024

    # <Marker name='default' at 24c4e10> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        pass
    else:
        _content = _cache_38555024
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_39069744 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_39069744
    append(u'</div>')
    if (_backup_attrs_39069312 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39069312
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_39070608 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24c42d0> name=None at 24c4290> -> _value
    _value = _static_38552272
    econtext['attrs'] = _value

    # <div ... (4:4)
    # --------------------------------------------------------
    append(u'<div>')
    _backup_default_39044592 = get('default', _marker)

    # <Marker name='default' at 24c49d0> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u'string:2 < 3' (4:32)> -> _cache_38552400
    try:
        _cache_38552400 = u'2 < 3'
    except:
        rcontext.setdefault('__error__', []).append((u'string:2 < 3', 4, 32, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u'string:2 < 3' (4:32)> value=<Marker name='default' at 24c4890> at 24c4250> -> _condition
    _expression = _cache_38552400

    # <Marker name='default' at 24c4890> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        pass
    else:
        _content = _cache_38552400
        if (_content is not None):
            _tt = type(_content)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _content = str(_content)
            else:
                if (_tt is str):
                    _content = decode(_content)
                else:
                    if (_tt is not unicode):
                        try:
                            _content = _content.__html__
                        except AttributeError:
                            _content = convert(_content)
                        else:
                            _content = _content()
        if (_content is not None):
            append(_content)
    if (_backup_default_39044592 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_39044592
    append(u'</div>')
    if (_backup_attrs_39070608 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39070608
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_37107256 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x2224850> name=None at 22241d0> -> _value
    _value = _static_35801168
    econtext['attrs'] = _value

    # <div ... (5:4)
    # --------------------------------------------------------
    append(u'<div>')
    _backup_default_35897424 = get('default', _marker)

    # <Marker name='default' at 2224250> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u"string:3 ${'<'} 4" (5:32)> -> _cache_38551888
    try:
        _cache_38551888 = '<'
        _cache_38551888 = ('%s%s%s' % ((u'3 ' if (u'3 ' is not None) else ''), (_cache_38551888 if (_cache_38551888 is not None) else ''), (u' 4' if (u' 4' is not None) else ''), ))
    except:
        rcontext.setdefault('__error__', []).append((u"string:3 ${'<'} 4", 5, 32, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u"string:3 ${'<'} 4" (5:32)> value=<Marker name='default' at 24c4110> at 24c40d0> -> _condition
    _expression = _cache_38551888

    # <Marker name='default' at 24c4110> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        pass
    else:
        _content = _cache_38551888
        if (_content is not None):
            _tt = type(_content)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _content = str(_content)
            else:
                if (_tt is str):
                    _content = decode(_content)
                else:
                    if (_tt is not unicode):
                        try:
                            _content = _content.__html__
                        except AttributeError:
                            _content = convert(_content)
                        else:
                            _content = _content()
        if (_content is not None):
            append(_content)
    if (_backup_default_35897424 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_35897424
    append(u'</div>')
    if (_backup_attrs_37107256 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_37107256
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_39055304 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x2224150> name=None at 2224dd0> -> _value
    _value = _static_35799376
    econtext['attrs'] = _value

    # <div ... (6:4)
    # --------------------------------------------------------
    append(u'<div>')
    _backup_default_39086560 = get('default', _marker)

    # <Marker name='default' at 2224a10> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u"'%d < %d' % (4, 5)" (6:32)> -> _cache_35801680
    try:
        _cache_35801680 = ('%d < %d' % (4, 5, ))
    except:
        rcontext.setdefault('__error__', []).append((u"'%d < %d' % (4, 5)", 6, 32, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u"'%d < %d' % (4, 5)" (6:32)> value=<Marker name='default' at 2224cd0> at 2224ed0> -> _condition
    _expression = _cache_35801680

    # <Marker name='default' at 2224cd0> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        pass
    else:
        _content = _cache_35801680
        if (_content is not None):
            _tt = type(_content)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _content = str(_content)
            else:
                if (_tt is str):
                    _content = decode(_content)
                else:
                    if (_tt is not unicode):
                        try:
                            _content = _content.__html__
                        except AttributeError:
                            _content = convert(_content)
                        else:
                            _content = _content()
        if (_content is not None):
            append(_content)
    if (_backup_default_39086560 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_39086560
    append(u'</div>')
    if (_backup_attrs_39055304 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39055304
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_default_39076928 = get('default', _marker)

    # <Marker name='default' at 24ca810> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u'content' (7:32)> -> _cache_38578128
    try:
        _cache_38578128 = getitem('content')
    except:
        rcontext.setdefault('__error__', []).append((u'content', 7, 32, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u'content' (7:32)> value=<Marker name='default' at 24cab50> at 24ca610> -> _condition
    _expression = _cache_38578128

    # <Marker name='default' at 24cab50> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        _backup_attrs_39051992 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x24cae50> name=None at 24cac10> -> _value
        _value = _static_38579792
        econtext['attrs'] = _value

        # <div ... (7:4)
        # --------------------------------------------------------
        append(u'<div />')
        if (_backup_attrs_39051992 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_39051992
    else:
        _content = _cache_38578128
        if (_content is not None):
            _tt = type(_content)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _content = str(_content)
            else:
                if (_tt is str):
                    _content = decode(_content)
                else:
                    if (_tt is not unicode):
                        try:
                            _content = _content.__html__
                        except AttributeError:
                            _content = convert(_content)
                        else:
                            _content = _content()
        if (_content is not None):
            append(_content)
    if (_backup_default_39076928 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_39076928
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</body>')
    if (_backup_attrs_39067944 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39067944
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</html>')
    if (_backup_attrs_39070032 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39070032
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
pass


import sys

def lookup_attr(obj, key):
    try:
        return getattr(obj, key)
    except AttributeError:
        exc = sys.exc_info()[1]
        try:
            get = obj.__getitem__
        except AttributeError:
            raise exc
        try:
            return get(key)
        except KeyError:
            raise exc

def exec_(code, globs=None, locs=None):
    """Execute code in a namespace."""
    if globs is None:
        frame = sys._getframe(1)
        globs = frame.f_globals
        if locs is None:
            locs = frame.f_locals
        del frame
    elif locs is None:
        locs = globs
    exec("""exec code in globs, locs""")


exec_("""def raise_with_traceback(exc, tb):
    raise type(exc), exc, tb
""")


def next(iter):
    return iter.next()



# -*- coding: utf-8 -*-
pass
import sys as _sys
pass
_static_36670736 = {u'src': u"${'#'}", u'alt': u'copyright (c) ${2010}', }
_static_36669072 = {u'class': u'ltr', }
_static_36669648 = {u'src': u'${None}', }
_static_36667984 = {}
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    _backup_attrs_36723672 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x22f8250> name=None at 22f8550> -> _value
    _value = _static_36667984
    econtext['attrs'] = _value

    # <html ... (1:0)
    # --------------------------------------------------------
    append(u'<html>')
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36648360 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x22f8690> name=None at 22f80d0> -> _value
    _value = _static_36669072
    econtext['attrs'] = _value

    # <body ... (2:2)
    # --------------------------------------------------------
    append(u'<body')
    _attr_class = u'ltr'
    if (_attr_class is not None):
        append((u' class="%s"' % _attr_class))
    append(u'>')
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36648216 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x22f8d10> name=None at 22f8d90> -> _value
    _value = _static_36670736
    econtext['attrs'] = _value

    # <img ... (3:4)
    # --------------------------------------------------------
    append(u'<img')
    _backup_default_36648432 = get('default', _marker)
    _value = u"${'#'}"
    econtext['default'] = _value

    # <Interpolation value=u"${'#'}" escape=True at 22f8a50> -> _attr_src

    # <Expression u"'#'" (3:16)> -> _attr_src
    try:
        _attr_src = '#'
    except:
        rcontext.setdefault('__error__', []).append((u"'#'", 3, 16, '<string>', _sys.exc_info()[1], ))
        raise

    _attr_src = _attr_src
    if (_attr_src is None):
        pass
    else:
        if (_attr_src is False):
            _attr_src = None
        else:
            _tt = type(_attr_src)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_src = unicode(_attr_src)
            else:
                try:
                    if (_tt is str):
                        _attr_src = decode(_attr_src)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_src = _attr_src.__html__
                            except:
                                _attr_src = convert(_attr_src)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_src = _attr_src()
                else:
                    if ((_attr_src is not None) and (re_needs_escape(_attr_src) is not None)):
                        if ('&' in _attr_src):
                            if (';' in _attr_src):
                                _attr_src = re_amp.sub('&amp;', _attr_src)
                            else:
                                _attr_src = _attr_src.replace('&', '&amp;')
                        if ('<' in _attr_src):
                            _attr_src = _attr_src.replace('<', '&lt;')
                        if ('>' in _attr_src):
                            _attr_src = _attr_src.replace('>', '&gt;')
                        if (u'"' in _attr_src):
                            _attr_src = _attr_src.replace(u'"', '&#34;')
    if (_attr_src is not None):
        append((u' src="%s"' % _attr_src))
    if (_backup_default_36648432 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_36648432
    _backup_default_39035896 = get('default', _marker)
    _value = u'copyright (c) ${2010}'
    econtext['default'] = _value

    # <Interpolation value=u'copyright (c) ${2010}' escape=True at 22f8090> -> _attr_alt

    # <Expression u'2010' (3:43)> -> _attr_alt
    try:
        _attr_alt = 2010
    except:
        rcontext.setdefault('__error__', []).append((u'2010', 3, 43, '<string>', _sys.exc_info()[1], ))
        raise

    _attr_alt = ('%s%s' % ((u'copyright (c) ' if (u'copyright (c) ' is not None) else ''), (_attr_alt if (_attr_alt is not None) else ''), ))
    if (_attr_alt is None):
        pass
    else:
        if (_attr_alt is False):
            _attr_alt = None
        else:
            _tt = type(_attr_alt)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_alt = unicode(_attr_alt)
            else:
                try:
                    if (_tt is str):
                        _attr_alt = decode(_attr_alt)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_alt = _attr_alt.__html__
                            except:
                                _attr_alt = convert(_attr_alt)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_alt = _attr_alt()
                else:
                    if ((_attr_alt is not None) and (re_needs_escape(_attr_alt) is not None)):
                        if ('&' in _attr_alt):
                            if (';' in _attr_alt):
                                _attr_alt = re_amp.sub('&amp;', _attr_alt)
                            else:
                                _attr_alt = _attr_alt.replace('&', '&amp;')
                        if ('<' in _attr_alt):
                            _attr_alt = _attr_alt.replace('<', '&lt;')
                        if ('>' in _attr_alt):
                            _attr_alt = _attr_alt.replace('>', '&gt;')
                        if (u'"' in _attr_alt):
                            _attr_alt = _attr_alt.replace(u'"', '&#34;')
    if (_attr_alt is not None):
        append((u' alt="%s"' % _attr_alt))
    if (_backup_default_39035896 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_39035896
    append(u' />')
    if (_backup_attrs_36648216 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36648216
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36650448 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x22f88d0> name=None at 22f8590> -> _value
    _value = _static_36669648
    econtext['attrs'] = _value

    # <img ... (4:4)
    # --------------------------------------------------------
    append(u'<img')
    _backup_default_36650232 = get('default', _marker)
    _value = u'${None}'
    econtext['default'] = _value

    # <Interpolation value=u'${None}' escape=True at 221fb90> -> _attr_src

    # <Expression u'None' (4:16)> -> _attr_src
    try:
        _attr_src = None
    except:
        rcontext.setdefault('__error__', []).append((u'None', 4, 16, '<string>', _sys.exc_info()[1], ))
        raise

    _attr_src = _attr_src
    if (_attr_src is None):
        pass
    else:
        if (_attr_src is False):
            _attr_src = None
        else:
            _tt = type(_attr_src)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_src = unicode(_attr_src)
            else:
                try:
                    if (_tt is str):
                        _attr_src = decode(_attr_src)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_src = _attr_src.__html__
                            except:
                                _attr_src = convert(_attr_src)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_src = _attr_src()
                else:
                    if ((_attr_src is not None) and (re_needs_escape(_attr_src) is not None)):
                        if ('&' in _attr_src):
                            if (';' in _attr_src):
                                _attr_src = re_amp.sub('&amp;', _attr_src)
                            else:
                                _attr_src = _attr_src.replace('&', '&amp;')
                        if ('<' in _attr_src):
                            _attr_src = _attr_src.replace('<', '&lt;')
                        if ('>' in _attr_src):
                            _attr_src = _attr_src.replace('>', '&gt;')
                        if (u'"' in _attr_src):
                            _attr_src = _attr_src.replace(u'"', '&#34;')
    if (_attr_src is not None):
        append((u' src="%s"' % _attr_src))
    if (_backup_default_36650232 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_36650232
    append(u' />')
    if (_backup_attrs_36650448 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36650448
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</body>')
    if (_backup_attrs_36648360 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36648360
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</html>')
    if (_backup_attrs_36723672 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36723672
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
pass


# -*- coding: utf-8 -*-
pass
import sys as _sys
pass
_static_39103696 = {u'href': u'http://repoze.org', u'id': u'link-id', u'rel': u'self', }
_static_39100880 = {u'xmlns': u'http://www.w3.org/1999/xhtml', }
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    _backup_attrs_37098488 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x254a1d0> name=None at 254a7d0> -> _value
    _value = _static_39100880
    econtext['attrs'] = _value

    # <div ... (1:0)
    # --------------------------------------------------------
    append(u'<div')
    _attr_xmlns = u'http://www.w3.org/1999/xhtml'
    if (_attr_xmlns is not None):
        append((u' xmlns="%s"' % _attr_xmlns))
    append(u'>')
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36810832 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x254acd0> name=None at 254ab10> -> _value
    _value = _static_39103696
    econtext['attrs'] = _value

    # <a ... (3:2)
    # --------------------------------------------------------
    append(u'<a')
    _attr_rel = u'self'
    if (_attr_rel is not None):
        append((u' rel="%s"' % _attr_rel))
    _backup_default_36710736 = get('default', _marker)
    _value = u'http://repoze.org'
    econtext['default'] = _value

    # <Expression u"'http://python.org'" (4:26)> -> _attr_href
    try:
        _attr_href = 'http://python.org'
    except:
        rcontext.setdefault('__error__', []).append((u"'http://python.org'", 4, 26, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_href is None):
        pass
    else:
        if (_attr_href is False):
            _attr_href = None
        else:
            _tt = type(_attr_href)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_href = unicode(_attr_href)
            else:
                try:
                    if (_tt is str):
                        _attr_href = decode(_attr_href)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_href = _attr_href.__html__
                            except:
                                _attr_href = convert(_attr_href)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_href = _attr_href()
                else:
                    if ((_attr_href is not None) and (re_needs_escape(_attr_href) is not None)):
                        if ('&' in _attr_href):
                            if (';' in _attr_href):
                                _attr_href = re_amp.sub('&amp;', _attr_href)
                            else:
                                _attr_href = _attr_href.replace('&', '&amp;')
                        if ('<' in _attr_href):
                            _attr_href = _attr_href.replace('<', '&lt;')
                        if ('>' in _attr_href):
                            _attr_href = _attr_href.replace('>', '&gt;')
                        if (u'"' in _attr_href):
                            _attr_href = _attr_href.replace(u'"', '&#34;')
    if (_attr_href is not None):
        append((u' href="%s"' % _attr_href))
    if (_backup_default_36710736 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_36710736
    _attr_id = u'link-id'
    if (_attr_id is not None):
        append((u' id="%s"' % _attr_id))
    append(u' />')
    if (_backup_attrs_36810832 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36810832
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</div>')
    if (_backup_attrs_37098488 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_37098488
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
pass


# -*- coding: utf-8 -*-
pass
from chameleon.utils import Placeholder as _Placeholder
import sys as _sys
pass
_static_36788688 = {}
_static_36744848 = {}
_static_38465168 = {}
_static_38401424 = {}
_static_38427088 = {}
_static_38579856 = {}
_static_37141712 = {}
_static_37140688 = {}
_static_36790160 = {}
_static_36789584 = {}
_static_37141776 = {}
_marker_default = _Placeholder()
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    _backup_attrs_39046608 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24aee90> name=None at 24ae750> -> _value
    _value = _static_38465168
    econtext['attrs'] = _value

    # <html ... (1:0)
    # --------------------------------------------------------
    append(u'<html>')
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_35794168 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24a59d0> name=None at 24a5690> -> _value
    _value = _static_38427088
    econtext['attrs'] = _value

    # <body ... (2:2)
    # --------------------------------------------------------
    append(u'<body>')
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_default_38452904 = get('default', _marker)

    # <Marker name='default' at 236b550> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u"'Hello world!'" (3:22)> -> _cache_36742672
    try:
        _cache_36742672 = 'Hello world!'
    except:
        rcontext.setdefault('__error__', []).append((u"'Hello world!'", 3, 22, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u"'Hello world!'" (3:22)> value=<Marker name='default' at 230a750> at 230ac90> -> _condition
    _expression = _cache_36742672

    # <Marker name='default' at 230a750> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        _backup_attrs_35754136 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x230ae90> name=None at 24a5e90> -> _value
        _value = _static_36744848
        econtext['attrs'] = _value

        # <div ... (3:4)
        # --------------------------------------------------------
        append(u'<div />')
        if (_backup_attrs_35754136 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_35754136
    else:
        _content = _cache_36742672
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_38452904 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_38452904
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_default_39065936 = get('default', _marker)

    # <Marker name='default' at 236b910> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u"'Hello world!'" (4:22)> -> _cache_37138960
    try:
        _cache_37138960 = 'Hello world!'
    except:
        rcontext.setdefault('__error__', []).append((u"'Hello world!'", 4, 22, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u"'Hello world!'" (4:22)> value=<Marker name='default' at 236bf10> at 236b250> -> _condition
    _expression = _cache_37138960

    # <Marker name='default' at 236bf10> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        _backup_attrs_39064568 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x236bcd0> name=None at 236b5d0> -> _value
        _value = _static_37141712
        econtext['attrs'] = _value

        # <div ... (4:4)
        # --------------------------------------------------------
        append(u'<div />')
        if (_backup_attrs_39064568 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_39064568
    else:
        _content = _cache_37138960
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_39065936 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_39065936
    _content_139955154988272 = u'1\n   2'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_default_39065000 = get('default', _marker)

    # <Marker name='default' at 236b650> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u"'Hello world!'" (5:22)> -> _cache_37140112
    try:
        _cache_37140112 = 'Hello world!'
    except:
        rcontext.setdefault('__error__', []).append((u"'Hello world!'", 5, 22, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u"'Hello world!'" (5:22)> value=<Marker name='default' at 236bb90> at 236b3d0> -> _condition
    _expression = _cache_37140112

    # <Marker name='default' at 236bb90> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        _backup_attrs_39067304 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x236b8d0> name=None at 236bbd0> -> _value
        _value = _static_37140688
        econtext['attrs'] = _value

        # <div ... (5:4)
        # --------------------------------------------------------
        append(u'<div />')
        if (_backup_attrs_39067304 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_39067304
    else:
        _content = _cache_37140112
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_39065000 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_39065000
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_default_39095472 = get('default', _marker)

    # <Marker name='default' at 249f290> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u"'Hello world!'" (6:22)> -> _cache_38401040
    try:
        _cache_38401040 = 'Hello world!'
    except:
        rcontext.setdefault('__error__', []).append((u"'Hello world!'", 6, 22, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u"'Hello world!'" (6:22)> value=<Marker name='default' at 249f750> at 249f210> -> _condition
    _expression = _cache_38401040

    # <Marker name='default' at 249f750> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        _backup_attrs_39095400 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x236bd10> name=None at 236b590> -> _value
        _value = _static_37141776
        econtext['attrs'] = _value

        # <div ... (6:4)
        # --------------------------------------------------------
        append(u'<div />')
        if (_backup_attrs_39095400 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_39095400
    else:
        _content = _cache_38401040
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_39095472 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_39095472
    _content_139955154988272 = u'3\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_default_35897496 = get('default', _marker)

    # <Marker name='default' at 24caa90> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u"'Hello world!'" (7:22)> -> _cache_38403600
    try:
        _cache_38403600 = 'Hello world!'
    except:
        rcontext.setdefault('__error__', []).append((u"'Hello world!'", 7, 22, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u"'Hello world!'" (7:22)> value=<Marker name='default' at 249fc50> at 249f950> -> _condition
    _expression = _cache_38403600

    # <Marker name='default' at 249fc50> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        _backup_attrs_35900880 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x249f590> name=None at 249f450> -> _value
        _value = _static_38401424
        econtext['attrs'] = _value

        # <div ... (7:4)
        # --------------------------------------------------------
        append(u'<div>')
        _content_139955154988272 = u'4'
        if (_content_139955154988272 is not None):
            append(_content_139955154988272)
        append(u'</div>')
        if (_backup_attrs_35900880 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_35900880
    else:
        _content = _cache_38403600
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_35897496 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_35897496
    _content_139955154988272 = u'5\n   6'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_default_38618392 = get('default', _marker)

    # <Marker name='default' at 24ca150> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u"'Hello world!'" (8:22)> -> _cache_38578576
    try:
        _cache_38578576 = 'Hello world!'
    except:
        rcontext.setdefault('__error__', []).append((u"'Hello world!'", 8, 22, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u"'Hello world!'" (8:22)> value=<Marker name='default' at 24cadd0> at 24caa10> -> _condition
    _expression = _cache_38578576

    # <Marker name='default' at 24cadd0> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        _backup_attrs_35899152 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x24cae90> name=None at 24ca510> -> _value
        _value = _static_38579856
        econtext['attrs'] = _value

        # <div ... (8:4)
        # --------------------------------------------------------
        append(u'<div>')
        append(u'</div>')
        if (_backup_attrs_35899152 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_35899152
    else:
        _content = _cache_38578576
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_38618392 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_38618392
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_default_38617960 = get('default', _marker)

    # <Marker name='default' at 2315510> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u'1' (9:22)> -> _cache_36790096
    try:
        _cache_36790096 = 1
    except:
        rcontext.setdefault('__error__', []).append((u'1', 9, 22, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u'1' (9:22)> value=<Marker name='default' at 2315690> at 23155d0> -> _condition
    _expression = _cache_36790096

    # <Marker name='default' at 2315690> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        _backup_attrs_38618320 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x2315f90> name=None at 23154d0> -> _value
        _value = _static_36790160
        econtext['attrs'] = _value

        # <div ... (9:4)
        # --------------------------------------------------------
        append(u'<div />')
        if (_backup_attrs_38618320 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_38618320
    else:
        _content = _cache_36790096
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_38617960 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_38617960
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_default_38631256 = get('default', _marker)

    # <Marker name='default' at 2315dd0> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u'1.0' (10:22)> -> _cache_36789200
    try:
        _cache_36789200 = 1.0
    except:
        rcontext.setdefault('__error__', []).append((u'1.0', 10, 22, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u'1.0' (10:22)> value=<Marker name='default' at 2315c10> at 2315a10> -> _condition
    _expression = _cache_36789200

    # <Marker name='default' at 2315c10> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        _backup_attrs_38619832 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x2315d50> name=None at 2315190> -> _value
        _value = _static_36789584
        econtext['attrs'] = _value

        # <div ... (10:4)
        # --------------------------------------------------------
        append(u'<div />')
        if (_backup_attrs_38619832 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_38619832
    else:
        _content = _cache_36789200
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_38631256 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_38631256
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_default_38647928 = get('default', _marker)

    # <Marker name='default' at 2315290> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u'True' (11:22)> -> _cache_36789072
    try:
        _cache_36789072 = True
    except:
        rcontext.setdefault('__error__', []).append((u'True', 11, 22, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u'True' (11:22)> value=<Marker name='default' at 23157d0> at 2315b90> -> _condition
    _expression = _cache_36789072

    # <Marker name='default' at 23157d0> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        _backup_attrs_39044664 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x23159d0> name=None at 2315110> -> _value
        _value = _static_36788688
        econtext['attrs'] = _value

        # <div ... (11:4)
        # --------------------------------------------------------
        append(u'<div />')
        if (_backup_attrs_39044664 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_39044664
    else:
        _content = _cache_36789072
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_38647928 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_38647928
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</body>')
    if (_backup_attrs_35794168 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_35794168
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</html>')
    if (_backup_attrs_39046608 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39046608
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
pass


# -*- coding: utf-8 -*-
pass
import sys as _sys
pass
_static_39975056 = {}
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')

    def _slot_title(stream, econtext, rcontext, _i18n_domain=_i18n_domain):
        getitem = econtext.__getitem__
        get = econtext.get
        _backup_kind_37140176 = get('kind', _marker)

        # <Expression u"'New'" (2:50)> -> _value
        try:
            _value = 'New'
        except:
            rcontext.setdefault('__error__', []).append((u"'New'", 2, 50, '<string>', _sys.exc_info()[1], ))
            raise

        econtext['kind'] = _value
        _backup_attrs_38600784 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x261f890> name=None at 261fc50> -> _value
        _value = _static_39975056
        econtext['attrs'] = _value

        # <title ... (2:2)
        # --------------------------------------------------------
        append(u'<title>')

        # <Expression u'kind' (3:6)> -> _content_139955154988272
        try:
            _content_139955154988272 = getitem('kind')
        except:
            rcontext.setdefault('__error__', []).append((u'kind', 3, 6, '<string>', _sys.exc_info()[1], ))
            raise

        if (_content_139955154988272 is None):
            pass
        else:
            if (_content_139955154988272 is False):
                _content_139955154988272 = None
            else:
                _tt = type(_content_139955154988272)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content_139955154988272 = unicode(_content_139955154988272)
                else:
                    try:
                        if (_tt is str):
                            _content_139955154988272 = decode(_content_139955154988272)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content_139955154988272 = _content_139955154988272.__html__
                                except:
                                    _content_139955154988272 = convert(_content_139955154988272)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content_139955154988272 = _content_139955154988272()
                    else:
                        if ((_content_139955154988272 is not None) and (re_needs_escape(_content_139955154988272) is not None)):
                            if ('&' in _content_139955154988272):
                                if (';' in _content_139955154988272):
                                    _content_139955154988272 = re_amp.sub('&amp;', _content_139955154988272)
                                else:
                                    _content_139955154988272 = _content_139955154988272.replace('&', '&amp;')
                            if ('<' in _content_139955154988272):
                                _content_139955154988272 = _content_139955154988272.replace('<', '&lt;')
                            if ('>' in _content_139955154988272):
                                _content_139955154988272 = _content_139955154988272.replace('>', '&gt;')
                            if ('\x00' in _content_139955154988272):
                                _content_139955154988272 = _content_139955154988272.replace('\x00', '&#34;')
        _content_139955154988272 = ('%s%s%s' % ((u'\n    ' if (u'\n    ' is not None) else ''), (_content_139955154988272 if (_content_139955154988272 is not None) else ''), (u' title\n  ' if (u' title\n  ' is not None) else ''), ))
        if (_content_139955154988272 is not None):
            append(_content_139955154988272)
        append(u'</title>')
        if (_backup_attrs_38600784 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_38600784
        if (_backup_kind_37140176 is _marker):
            del econtext['kind']
        else:
            econtext['kind'] = _backup_kind_37140176
    try:
        _slots = getitem(u'_slot_title')
    except:
        _slots = econtext[u'_slot_title'] = [_slot_title, ]
    else:
        _slots.append(_slot_title)

    # <Expression u"load('032-master-template.pt').macros['main']" (1:23)> -> _macro
    try:
        _macro = getitem('load')('032-master-template.pt').macros['main']
    except:
        rcontext.setdefault('__error__', []).append((u"load('032-master-template.pt').macros['main']", 1, 23, '<string>', _sys.exc_info()[1], ))
        raise

    _macro.include(stream, econtext.copy(), rcontext)
    econtext.update(rcontext)
pass


# -*- coding: utf-8 -*-
pass
import sys as _sys
pass
_static_35829392 = {}
_static_36669456 = {}
_static_36669712 = {u'class': u'static', }
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    _backup_attrs_35754928 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x222b690> name=None at 222bb50> -> _value
    _value = _static_35829392
    econtext['attrs'] = _value

    # <html ... (1:0)
    # --------------------------------------------------------
    append(u'<html>')
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_35872992 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x22f8810> name=None at 22f8210> -> _value
    _value = _static_36669456
    econtext['attrs'] = _value

    # <body ... (2:2)
    # --------------------------------------------------------
    append(u'<body>')

    # <Expression u'nothing' (3:6)> -> _content_139955154988272
    try:
        _content_139955154988272 = getitem('nothing')
    except:
        rcontext.setdefault('__error__', []).append((u'nothing', 3, 6, '<string>', _sys.exc_info()[1], ))
        raise

    if (_content_139955154988272 is None):
        pass
    else:
        if (_content_139955154988272 is False):
            _content_139955154988272 = None
        else:
            _tt = type(_content_139955154988272)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _content_139955154988272 = unicode(_content_139955154988272)
            else:
                try:
                    if (_tt is str):
                        _content_139955154988272 = decode(_content_139955154988272)
                    else:
                        if (_tt is not unicode):
                            try:
                                _content_139955154988272 = _content_139955154988272.__html__
                            except:
                                _content_139955154988272 = convert(_content_139955154988272)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _content_139955154988272 = _content_139955154988272()
                else:
                    if ((_content_139955154988272 is not None) and (re_needs_escape(_content_139955154988272) is not None)):
                        if ('&' in _content_139955154988272):
                            if (';' in _content_139955154988272):
                                _content_139955154988272 = re_amp.sub('&amp;', _content_139955154988272)
                            else:
                                _content_139955154988272 = _content_139955154988272.replace('&', '&amp;')
                        if ('<' in _content_139955154988272):
                            _content_139955154988272 = _content_139955154988272.replace('<', '&lt;')
                        if ('>' in _content_139955154988272):
                            _content_139955154988272 = _content_139955154988272.replace('>', '&gt;')
                        if ('\x00' in _content_139955154988272):
                            _content_139955154988272 = _content_139955154988272.replace('\x00', '&#34;')
    _content_139955154988272 = ('%s%s%s' % ((u'\n    ' if (u'\n    ' is not None) else ''), (_content_139955154988272 if (_content_139955154988272 is not None) else ''), (u'\n    ' if (u'\n    ' is not None) else ''), ))
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_35755576 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x22f8910> name=None at 22f8f10> -> _value
    _value = _static_36669712
    econtext['attrs'] = _value

    # <div ... (4:4)
    # --------------------------------------------------------
    append(u'<div')
    _backup_default_35755720 = get('default', _marker)
    _value = u'static'
    econtext['default'] = _value

    # <Expression u'string:dynamic' (4:31)> -> _attr_class
    try:
        _attr_class = u'dynamic'
    except:
        rcontext.setdefault('__error__', []).append((u'string:dynamic', 4, 31, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_class is None):
        pass
    else:
        if (_attr_class is False):
            _attr_class = None
        else:
            _tt = type(_attr_class)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_class = unicode(_attr_class)
            else:
                try:
                    if (_tt is str):
                        _attr_class = decode(_attr_class)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_class = _attr_class.__html__
                            except:
                                _attr_class = convert(_attr_class)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_class = _attr_class()
                else:
                    if ((_attr_class is not None) and (re_needs_escape(_attr_class) is not None)):
                        if ('&' in _attr_class):
                            if (';' in _attr_class):
                                _attr_class = re_amp.sub('&amp;', _attr_class)
                            else:
                                _attr_class = _attr_class.replace('&', '&amp;')
                        if ('<' in _attr_class):
                            _attr_class = _attr_class.replace('<', '&lt;')
                        if ('>' in _attr_class):
                            _attr_class = _attr_class.replace('>', '&gt;')
                        if (u'"' in _attr_class):
                            _attr_class = _attr_class.replace(u'"', '&#34;')
    if (_attr_class is not None):
        append((u' class="%s"' % _attr_class))
    if (_backup_default_35755720 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_35755720
    append(u'>')

    # <Expression u"attrs['class']" (5:8)> -> _content_139955154988272
    try:
        _content_139955154988272 = getitem('attrs')['class']
    except:
        rcontext.setdefault('__error__', []).append((u"attrs['class']", 5, 8, '<string>', _sys.exc_info()[1], ))
        raise

    if (_content_139955154988272 is None):
        pass
    else:
        if (_content_139955154988272 is False):
            _content_139955154988272 = None
        else:
            _tt = type(_content_139955154988272)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _content_139955154988272 = unicode(_content_139955154988272)
            else:
                try:
                    if (_tt is str):
                        _content_139955154988272 = decode(_content_139955154988272)
                    else:
                        if (_tt is not unicode):
                            try:
                                _content_139955154988272 = _content_139955154988272.__html__
                            except:
                                _content_139955154988272 = convert(_content_139955154988272)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _content_139955154988272 = _content_139955154988272()
                else:
                    if ((_content_139955154988272 is not None) and (re_needs_escape(_content_139955154988272) is not None)):
                        if ('&' in _content_139955154988272):
                            if (';' in _content_139955154988272):
                                _content_139955154988272 = re_amp.sub('&amp;', _content_139955154988272)
                            else:
                                _content_139955154988272 = _content_139955154988272.replace('&', '&amp;')
                        if ('<' in _content_139955154988272):
                            _content_139955154988272 = _content_139955154988272.replace('<', '&lt;')
                        if ('>' in _content_139955154988272):
                            _content_139955154988272 = _content_139955154988272.replace('>', '&gt;')
                        if ('\x00' in _content_139955154988272):
                            _content_139955154988272 = _content_139955154988272.replace('\x00', '&#34;')
    _content_139955154988272 = ('%s%s%s' % ((u'\n      ' if (u'\n      ' is not None) else ''), (_content_139955154988272 if (_content_139955154988272 is not None) else ''), (u'\n    ' if (u'\n    ' is not None) else ''), ))
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</div>')
    if (_backup_attrs_35755576 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_35755576
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</body>')
    if (_backup_attrs_35872992 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_35872992
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</html>')
    if (_backup_attrs_35754928 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_35754928
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
pass


# -*- coding: utf-8 -*-
pass
from chameleon.utils import Placeholder as _Placeholder
import sys as _sys
pass
_static_38936400 = {}
_static_38932624 = {}
_static_39101904 = {u'xmlns': u'http://www.w3.org/1999/xhtml', }
_static_39103376 = {u'style': u"'hij'", u'id': u'test', u'onClick': u'', u'class': u'dummy', }
_static_38935952 = {}
_static_38934352 = {}
_marker_default = _Placeholder()
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    _backup_attrs_39046104 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x254a5d0> name=None at 249f050> -> _value
    _value = _static_39101904
    econtext['attrs'] = _value

    # <div ... (1:0)
    # --------------------------------------------------------
    append(u'<div')
    _attr_xmlns = u'http://www.w3.org/1999/xhtml'
    if (_attr_xmlns is not None):
        append((u' xmlns="%s"' % _attr_xmlns))
    append(u'>')
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_a_35883472 = get('a', _marker)

    # <Expression u"'abc'" (6:22)> -> _value
    try:
        _value = 'abc'
    except:
        rcontext.setdefault('__error__', []).append((u"'abc'", 6, 22, '<string>', _sys.exc_info()[1], ))
        raise

    econtext['a'] = _value
    _backup_attrs_38523464 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x254ab90> name=None at 254aa50> -> _value
    _value = _static_39103376
    econtext['attrs'] = _value

    # <span ... (3:2)
    # --------------------------------------------------------
    append(u'<span')
    _attr_id = u'test'
    if (_attr_id is not None):
        append((u' id="%s"' % _attr_id))
    _backup_default_39046968 = get('default', _marker)
    _value = u'dummy'
    econtext['default'] = _value

    # <Expression u"'def' + a + default" (7:30)> -> _attr_class
    try:
        _attr_class = (('def' + getitem('a')) + getitem('default'))
    except:
        rcontext.setdefault('__error__', []).append((u"'def' + a + default", 7, 30, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_class is None):
        pass
    else:
        if (_attr_class is False):
            _attr_class = None
        else:
            _tt = type(_attr_class)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_class = unicode(_attr_class)
            else:
                try:
                    if (_tt is str):
                        _attr_class = decode(_attr_class)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_class = _attr_class.__html__
                            except:
                                _attr_class = convert(_attr_class)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_class = _attr_class()
                else:
                    if ((_attr_class is not None) and (re_needs_escape(_attr_class) is not None)):
                        if ('&' in _attr_class):
                            if (';' in _attr_class):
                                _attr_class = re_amp.sub('&amp;', _attr_class)
                            else:
                                _attr_class = _attr_class.replace('&', '&amp;')
                        if ('<' in _attr_class):
                            _attr_class = _attr_class.replace('<', '&lt;')
                        if ('>' in _attr_class):
                            _attr_class = _attr_class.replace('>', '&gt;')
                        if (u'"' in _attr_class):
                            _attr_class = _attr_class.replace(u'"', '&#34;')
    if (_attr_class is not None):
        append((u'\n        class="%s"' % _attr_class))
    if (_backup_default_39046968 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_39046968
    _backup_default_38526416 = get('default', _marker)
    _value = u''
    econtext['default'] = _value

    # <Expression u"'alert();'" (7:70)> -> _attr_onClick
    try:
        _attr_onClick = 'alert();'
    except:
        rcontext.setdefault('__error__', []).append((u"'alert();'", 7, 70, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_onClick is None):
        pass
    else:
        if (_attr_onClick is False):
            _attr_onClick = None
        else:
            _tt = type(_attr_onClick)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_onClick = unicode(_attr_onClick)
            else:
                try:
                    if (_tt is str):
                        _attr_onClick = decode(_attr_onClick)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_onClick = _attr_onClick.__html__
                            except:
                                _attr_onClick = convert(_attr_onClick)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_onClick = _attr_onClick()
                else:
                    if ((_attr_onClick is not None) and (re_needs_escape(_attr_onClick) is not None)):
                        if ('&' in _attr_onClick):
                            if (';' in _attr_onClick):
                                _attr_onClick = re_amp.sub('&amp;', _attr_onClick)
                            else:
                                _attr_onClick = _attr_onClick.replace('&', '&amp;')
                        if ('<' in _attr_onClick):
                            _attr_onClick = _attr_onClick.replace('<', '&lt;')
                        if ('>' in _attr_onClick):
                            _attr_onClick = _attr_onClick.replace('>', '&gt;')
                        if (u'"' in _attr_onClick):
                            _attr_onClick = _attr_onClick.replace(u'"', '&#34;')
    if (_attr_onClick is not None):
        append((u'\n        onClick="%s"' % _attr_onClick))
    if (_backup_default_38526416 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_38526416
    _backup_default_38524760 = get('default', _marker)
    _value = None
    econtext['default'] = _value

    # <Expression u"'hij'" (7:56)> -> _attr_style
    try:
        _attr_style = 'hij'
    except:
        rcontext.setdefault('__error__', []).append((u"'hij'", 7, 56, '<string>', _sys.exc_info()[1], ))
        raise

    if (_attr_style is None):
        pass
    else:
        if (_attr_style is False):
            _attr_style = None
        else:
            _tt = type(_attr_style)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _attr_style = unicode(_attr_style)
            else:
                try:
                    if (_tt is str):
                        _attr_style = decode(_attr_style)
                    else:
                        if (_tt is not unicode):
                            try:
                                _attr_style = _attr_style.__html__
                            except:
                                _attr_style = convert(_attr_style)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _attr_style = _attr_style()
                else:
                    if ((_attr_style is not None) and (re_needs_escape(_attr_style) is not None)):
                        if ('&' in _attr_style):
                            if (';' in _attr_style):
                                _attr_style = re_amp.sub('&amp;', _attr_style)
                            else:
                                _attr_style = _attr_style.replace('&', '&amp;')
                        if ('<' in _attr_style):
                            _attr_style = _attr_style.replace('<', '&lt;')
                        if ('>' in _attr_style):
                            _attr_style = _attr_style.replace('>', '&gt;')
                        if ('"' in _attr_style):
                            _attr_style = _attr_style.replace('"', '&#34;')
    if (_attr_style is not None):
        append((u' style="%s"' % _attr_style))
    if (_backup_default_38524760 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_38524760
    append('>')
    _backup_default_38525480 = get('default', _marker)

    # <Marker name='default' at 254a9d0> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u"a + 'ghi'" (8:21)> -> _cache_39100816
    try:
        _cache_39100816 = (getitem('a') + 'ghi')
    except:
        rcontext.setdefault('__error__', []).append((u"a + 'ghi'", 8, 21, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u"a + 'ghi'" (8:21)> value=<Marker name='default' at 254a890> at 254a090> -> _condition
    _expression = _cache_39100816

    # <Marker name='default' at 254a890> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        pass
    else:
        _content = _cache_39100816
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_38525480 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_38525480
    append(u'</span>')
    if (_backup_attrs_38523464 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_38523464
    if (_backup_a_35883472 is _marker):
        del econtext['a']
    else:
        econtext['a'] = _backup_a_35883472
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_default_39596544 = get('default', _marker)

    # <Marker name='default' at 2521f90> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u"'Hello World!'" (9:21)> -> _cache_38934928
    try:
        _cache_38934928 = 'Hello World!'
    except:
        rcontext.setdefault('__error__', []).append((u"'Hello World!'", 9, 21, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u"'Hello World!'" (9:21)> value=<Marker name='default' at 2521c50> at 2521b50> -> _condition
    _expression = _cache_38934928

    # <Marker name='default' at 2521c50> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        _backup_attrs_38526488 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x2521d90> name=None at 2521e10> -> _value
        _value = _static_38935952
        econtext['attrs'] = _value

        # <span ... (9:2)
        # --------------------------------------------------------
        append(u'<span>')
        _content_139955154988272 = u'Hello '
        if (_content_139955154988272 is not None):
            append(_content_139955154988272)
        _backup_attrs_36682352 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x2521750> name=None at 2521ed0> -> _value
        _value = _static_38934352
        econtext['attrs'] = _value

        # <b ... (9:43)
        # --------------------------------------------------------
        append(u'<b>')
        _content_139955154988272 = u'Universe'
        if (_content_139955154988272 is not None):
            append(_content_139955154988272)
        append(u'</b>')
        if (_backup_attrs_36682352 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_36682352
        _content_139955154988272 = u'!'
        if (_content_139955154988272 is not None):
            append(_content_139955154988272)
        append(u'</span>')
        if (_backup_attrs_38526488 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_38526488
    else:
        _content = _cache_38934928
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_39596544 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_39596544
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_default_36682856 = get('default', _marker)

    # <Marker name='default' at 2521710> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u"'Hello World!'" (10:21)> -> _cache_38932752
    try:
        _cache_38932752 = 'Hello World!'
    except:
        rcontext.setdefault('__error__', []).append((u"'Hello World!'", 10, 21, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u"'Hello World!'" (10:21)> value=<Marker name='default' at 2521410> at 25214d0> -> _condition
    _expression = _cache_38932752

    # <Marker name='default' at 2521410> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        _backup_attrs_36682928 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x2521090> name=None at 25215d0> -> _value
        _value = _static_38932624
        econtext['attrs'] = _value

        # <span ... (10:2)
        # --------------------------------------------------------
        append(u'<span>')
        _backup_attrs_35804656 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x2521f50> name=None at 2521490> -> _value
        _value = _static_38936400
        econtext['attrs'] = _value

        # <b ... (10:37)
        # --------------------------------------------------------
        append(u'<b>')
        _content_139955154988272 = u'Hello Universe!'
        if (_content_139955154988272 is not None):
            append(_content_139955154988272)
        append(u'</b>')
        if (_backup_attrs_35804656 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_35804656
        append(u'</span>')
        if (_backup_attrs_36682928 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_36682928
    else:
        _content = _cache_38932752
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_36682856 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_36682856
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</div>')
    if (_backup_attrs_39046104 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39046104
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
pass


# -*- coding: utf-8 -*-
pass
from chameleon.utils import Placeholder as _Placeholder
import sys as _sys
pass
_static_38464336 = {}
_static_38462992 = {}
_static_35800464 = {}
_static_38589648 = {}
_static_35799184 = {}
_static_38591312 = {}
_marker_default = _Placeholder()
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    _backup_attrs_38435944 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x2224590> name=None at 2224e10> -> _value
    _value = _static_35800464
    econtext['attrs'] = _value

    # <html ... (1:0)
    # --------------------------------------------------------
    append(u'<html>')
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_35756224 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x2224090> name=None at 22243d0> -> _value
    _value = _static_35799184
    econtext['attrs'] = _value

    # <body ... (2:2)
    # --------------------------------------------------------
    append(u'<body>')
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_35757952 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24cdb50> name=None at 24cde50> -> _value
    _value = _static_38591312
    econtext['attrs'] = _value

    # <div ... (3:4)
    # --------------------------------------------------------
    append(u'<div>')
    _backup_default_35754928 = get('default', _marker)

    # <Marker name='default' at 24cd810> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u'message' (3:27)> -> _cache_35800272
    try:
        _cache_35800272 = getitem('message')
    except:
        rcontext.setdefault('__error__', []).append((u'message', 3, 27, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u'message' (3:27)> value=<Marker name='default' at 2317990> at 2317810> -> _condition
    _expression = _cache_35800272

    # <Marker name='default' at 2317990> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        pass
    else:
        _content = _cache_35800272
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_35754928 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_35754928
    append(u'</div>')
    if (_backup_attrs_35757952 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_35757952
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_35754136 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24cd4d0> name=None at 24cd390> -> _value
    _value = _static_38589648
    econtext['attrs'] = _value

    # <div ... (4:4)
    # --------------------------------------------------------
    append(u'<div>')
    _backup_default_35755144 = get('default', _marker)

    # <Marker name='default' at 24cd590> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u'message' (4:32)> -> _cache_38591632
    try:
        _cache_38591632 = getitem('message')
    except:
        rcontext.setdefault('__error__', []).append((u'message', 4, 32, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u'message' (4:32)> value=<Marker name='default' at 24cd7d0> at 24cde90> -> _condition
    _expression = _cache_38591632

    # <Marker name='default' at 24cd7d0> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        pass
    else:
        _content = _cache_38591632
        if (_content is not None):
            _tt = type(_content)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _content = str(_content)
            else:
                if (_tt is str):
                    _content = decode(_content)
                else:
                    if (_tt is not unicode):
                        try:
                            _content = _content.__html__
                        except AttributeError:
                            _content = convert(_content)
                        else:
                            _content = _content()
        if (_content is not None):
            append(_content)
    if (_backup_default_35755144 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_35755144
    append(u'</div>')
    if (_backup_attrs_35754136 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_35754136
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_35756728 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24aeb50> name=None at 24aead0> -> _value
    _value = _static_38464336
    econtext['attrs'] = _value

    # <div ... (5:4)
    # --------------------------------------------------------
    append(u'<div>')
    _backup_default_35756008 = get('default', _marker)

    # <Marker name='default' at 24aeb90> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u'string:${message}' (5:27)> -> _cache_38592208
    try:
        _cache_38592208 = getitem('message')
        _cache_38592208 = _cache_38592208
    except:
        rcontext.setdefault('__error__', []).append((u'string:${message}', 5, 27, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u'string:${message}' (5:27)> value=<Marker name='default' at 222be10> at 222bd50> -> _condition
    _expression = _cache_38592208

    # <Marker name='default' at 222be10> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        pass
    else:
        _content = _cache_38592208
        if (_content is None):
            pass
        else:
            if (_content is False):
                _content = None
            else:
                _tt = type(_content)
                if ((_tt is int) or (_tt is float) or (_tt is long)):
                    _content = unicode(_content)
                else:
                    try:
                        if (_tt is str):
                            _content = decode(_content)
                        else:
                            if (_tt is not unicode):
                                try:
                                    _content = _content.__html__
                                except:
                                    _content = convert(_content)
                                else:
                                    raise RuntimeError
                    except RuntimeError:
                        _content = _content()
                    else:
                        if ((_content is not None) and (re_needs_escape(_content) is not None)):
                            if ('&' in _content):
                                if (';' in _content):
                                    _content = re_amp.sub('&amp;', _content)
                                else:
                                    _content = _content.replace('&', '&amp;')
                            if ('<' in _content):
                                _content = _content.replace('<', '&lt;')
                            if ('>' in _content):
                                _content = _content.replace('>', '&gt;')
                            if ('\x00' in _content):
                                _content = _content.replace('\x00', '&#34;')
        if (_content is not None):
            append(_content)
    if (_backup_default_35756008 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_35756008
    append(u'</div>')
    if (_backup_attrs_35756728 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_35756728
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_39036616 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x24ae610> name=None at 24ae490> -> _value
    _value = _static_38462992
    econtext['attrs'] = _value

    # <div ... (6:4)
    # --------------------------------------------------------
    append(u'<div>')
    _backup_default_37197080 = get('default', _marker)

    # <Marker name='default' at 24ae410> -> _value
    _value = _marker_default
    econtext['default'] = _value

    # <Expression u'string:${message}' (6:32)> -> _cache_38465488
    try:
        _cache_38465488 = getitem('message')
        _cache_38465488 = _cache_38465488
    except:
        rcontext.setdefault('__error__', []).append((u'string:${message}', 6, 32, '<string>', _sys.exc_info()[1], ))
        raise


    # <Identity expression=<Expression u'string:${message}' (6:32)> value=<Marker name='default' at 24ae3d0> at 24ae190> -> _condition
    _expression = _cache_38465488

    # <Marker name='default' at 24ae3d0> -> _value
    _value = _marker_default
    _condition = (_expression is _value)
    if _condition:
        pass
    else:
        _content = _cache_38465488
        if (_content is not None):
            _tt = type(_content)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _content = str(_content)
            else:
                if (_tt is str):
                    _content = decode(_content)
                else:
                    if (_tt is not unicode):
                        try:
                            _content = _content.__html__
                        except AttributeError:
                            _content = convert(_content)
                        else:
                            _content = _content()
        if (_content is not None):
            append(_content)
    if (_backup_default_37197080 is _marker):
        del econtext['default']
    else:
        econtext['default'] = _backup_default_37197080
    append(u'</div>')
    if (_backup_attrs_39036616 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39036616

    # <Expression u'message' (7:6)> -> _content_139955154988272
    try:
        _content_139955154988272 = getitem('message')
    except:
        rcontext.setdefault('__error__', []).append((u'message', 7, 6, '<string>', _sys.exc_info()[1], ))
        raise

    if (_content_139955154988272 is None):
        pass
    else:
        if (_content_139955154988272 is False):
            _content_139955154988272 = None
        else:
            _tt = type(_content_139955154988272)
            if ((_tt is int) or (_tt is float) or (_tt is long)):
                _content_139955154988272 = unicode(_content_139955154988272)
            else:
                try:
                    if (_tt is str):
                        _content_139955154988272 = decode(_content_139955154988272)
                    else:
                        if (_tt is not unicode):
                            try:
                                _content_139955154988272 = _content_139955154988272.__html__
                            except:
                                _content_139955154988272 = convert(_content_139955154988272)
                            else:
                                raise RuntimeError
                except RuntimeError:
                    _content_139955154988272 = _content_139955154988272()
                else:
                    if ((_content_139955154988272 is not None) and (re_needs_escape(_content_139955154988272) is not None)):
                        if ('&' in _content_139955154988272):
                            if (';' in _content_139955154988272):
                                _content_139955154988272 = re_amp.sub('&amp;', _content_139955154988272)
                            else:
                                _content_139955154988272 = _content_139955154988272.replace('&', '&amp;')
                        if ('<' in _content_139955154988272):
                            _content_139955154988272 = _content_139955154988272.replace('<', '&lt;')
                        if ('>' in _content_139955154988272):
                            _content_139955154988272 = _content_139955154988272.replace('>', '&gt;')
                        if ('\x00' in _content_139955154988272):
                            _content_139955154988272 = _content_139955154988272.replace('\x00', '&#34;')
    _content_139955154988272 = ('%s%s%s' % ((u'\n    ' if (u'\n    ' is not None) else ''), (_content_139955154988272 if (_content_139955154988272 is not None) else ''), (u'\n  ' if (u'\n  ' is not None) else ''), ))
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</body>')
    if (_backup_attrs_35756224 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_35756224
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</html>')
    if (_backup_attrs_38435944 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_38435944
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
pass


# -*- coding: utf-8 -*-
pass
from chameleon.utils import Placeholder as _Placeholder
import sys as _sys
pass
_static_39973456 = {u'id': u'content', }
_static_38402704 = {}
_static_40208784 = {}
_static_38935504 = {}
_static_38935440 = {}
_static_39975056 = {u'id': u'footer', }
_marker_default = _Placeholder()
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render_main(stream, econtext, rcontext):
    try:
        _slot_title = getitem(u'_slot_title').pop()
    except:
        _slot_title = None

    try:
        _slot_content = getitem(u'_slot_content').pop()
    except:
        _slot_content = None

    try:
        _slot_body_footer = getitem(u'_slot_body_footer').pop()
    except:
        _slot_body_footer = None

    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    _backup_content_36741456 = get('content', _marker)

    # <Expression u'nothing' (1:52)> -> _value
    try:
        _value = getitem('nothing')
    except:
        rcontext.setdefault('__error__', []).append((u'nothing', 1, 52, '<string>', _sys.exc_info()[1], ))
        raise

    econtext['content'] = _value
    _backup_attrs_39812776 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x2658990> name=None at 2658710> -> _value
    _value = _static_40208784
    econtext['attrs'] = _value

    # <html ... (1:0)
    # --------------------------------------------------------
    append(u'<html>')
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_38435368 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x2521bd0> name=None at 2521f90> -> _value
    _value = _static_38935504
    econtext['attrs'] = _value

    # <head ... (2:2)
    # --------------------------------------------------------
    append(u'<head>')
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    if (_slot_title is None):
        _backup_has_title_38932944 = get('has_title', _marker)

        # <Expression u'exists: title' (4:33)> -> _value
        try:
            try:
                _ignore = getitem('title')
            except (AttributeError, LookupError, TypeError, NameError, KeyError, ):
                _value = 0
            else:
                _value = 1
        except:
            rcontext.setdefault('__error__', []).append((u'exists: title', 4, 33, '<string>', _sys.exc_info()[1], ))
            raise

        econtext['has_title'] = _value
        _backup_attrs_36811840 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x2521b90> name=None at 2521050> -> _value
        _value = _static_38935440
        econtext['attrs'] = _value

        # <title ... (3:4)
        # --------------------------------------------------------
        append(u'<title>')
        _backup_default_38436088 = get('default', _marker)

        # <Marker name='default' at 2521490> -> _value
        _value = _marker_default
        econtext['default'] = _value

        # <Expression u'title if has_title else default' (5:24)> -> _cache_38935120
        try:
            _cache_38935120 = (getitem('title') if getitem('has_title') else getitem('default'))
        except:
            rcontext.setdefault('__error__', []).append((u'title if has_title else default', 5, 24, '<string>', _sys.exc_info()[1], ))
            raise


        # <Identity expression=<Expression u'title if has_title else default' (5:24)> value=<Marker name='default' at 2521f50> at 2521790> -> _condition
        _expression = _cache_38935120

        # <Marker name='default' at 2521f50> -> _value
        _value = _marker_default
        _condition = (_expression is _value)
        if _condition:
            _content_139955154988272 = u'Master template'
            if (_content_139955154988272 is not None):
                append(_content_139955154988272)
        else:
            _content = _cache_38935120
            if (_content is None):
                pass
            else:
                if (_content is False):
                    _content = None
                else:
                    _tt = type(_content)
                    if ((_tt is int) or (_tt is float) or (_tt is long)):
                        _content = unicode(_content)
                    else:
                        try:
                            if (_tt is str):
                                _content = decode(_content)
                            else:
                                if (_tt is not unicode):
                                    try:
                                        _content = _content.__html__
                                    except:
                                        _content = convert(_content)
                                    else:
                                        raise RuntimeError
                        except RuntimeError:
                            _content = _content()
                        else:
                            if ((_content is not None) and (re_needs_escape(_content) is not None)):
                                if ('&' in _content):
                                    if (';' in _content):
                                        _content = re_amp.sub('&amp;', _content)
                                    else:
                                        _content = _content.replace('&', '&amp;')
                                if ('<' in _content):
                                    _content = _content.replace('<', '&lt;')
                                if ('>' in _content):
                                    _content = _content.replace('>', '&gt;')
                                if ('\x00' in _content):
                                    _content = _content.replace('\x00', '&#34;')
            if (_content is not None):
                append(_content)
        if (_backup_default_38436088 is _marker):
            del econtext['default']
        else:
            econtext['default'] = _backup_default_38436088
        append(u'</title>')
        if (_backup_attrs_36811840 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_36811840
        if (_backup_has_title_38932944 is _marker):
            del econtext['has_title']
        else:
            econtext['has_title'] = _backup_has_title_38932944
    else:
        _slot_title(stream, econtext.copy(), econtext)
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</head>')
    if (_backup_attrs_38435368 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_38435368
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36813640 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x249fa90> name=None at 249fc10> -> _value
    _value = _static_38402704
    econtext['attrs'] = _value

    # <body ... (7:2)
    # --------------------------------------------------------
    append(u'<body>')
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36813496 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x261f250> name=None at 261f210> -> _value
    _value = _static_39973456
    econtext['attrs'] = _value

    # <div ... (8:4)
    # --------------------------------------------------------
    append(u'<div')
    _attr_id = u'content'
    if (_attr_id is not None):
        append((u' id="%s"' % _attr_id))
    append(u'>')
    _content_139955154988272 = u'\n      '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    if (_slot_content is None):
        _content_139955154988272 = u'\n        '
        if (_content_139955154988272 is not None):
            append(_content_139955154988272)
        append(u'<!-- content here -->')
        _content_139955154988272 = u'\n      '
        if (_content_139955154988272 is not None):
            append(_content_139955154988272)
    else:
        _slot_content(stream, econtext.copy(), econtext)
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</div>')
    if (_backup_attrs_36813496 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36813496
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_36812632 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x261f890> name=None at 261fad0> -> _value
    _value = _static_39975056
    econtext['attrs'] = _value

    # <div ... (13:4)
    # --------------------------------------------------------
    append(u'<div')
    _attr_id = u'footer'
    if (_attr_id is not None):
        append((u' id="%s"' % _attr_id))
    append(u'>')
    _content_139955154988272 = u'\n      '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    if (_slot_body_footer is None):
        _backup_default_36811120 = get('default', _marker)

        # <Marker name='default' at 261f910> -> _value
        _value = _marker_default
        econtext['default'] = _value

        # <Expression u'nothing' (14:59)> -> _cache_39976784
        try:
            _cache_39976784 = getitem('nothing')
        except:
            rcontext.setdefault('__error__', []).append((u'nothing', 14, 59, '<string>', _sys.exc_info()[1], ))
            raise


        # <Identity expression=<Expression u'nothing' (14:59)> value=<Marker name='default' at 261fb50> at 261f6d0> -> _condition
        _expression = _cache_39976784

        # <Marker name='default' at 261fb50> -> _value
        _value = _marker_default
        _condition = (_expression is _value)
        if _condition:
            _content_139955154988272 = u'\n        '
            if (_content_139955154988272 is not None):
                append(_content_139955154988272)
            append(u'<!-- footer here -->')
            _content_139955154988272 = u'\n      '
            if (_content_139955154988272 is not None):
                append(_content_139955154988272)
        else:
            _content = _cache_39976784
            if (_content is None):
                pass
            else:
                if (_content is False):
                    _content = None
                else:
                    _tt = type(_content)
                    if ((_tt is int) or (_tt is float) or (_tt is long)):
                        _content = unicode(_content)
                    else:
                        try:
                            if (_tt is str):
                                _content = decode(_content)
                            else:
                                if (_tt is not unicode):
                                    try:
                                        _content = _content.__html__
                                    except:
                                        _content = convert(_content)
                                    else:
                                        raise RuntimeError
                        except RuntimeError:
                            _content = _content()
                        else:
                            if ((_content is not None) and (re_needs_escape(_content) is not None)):
                                if ('&' in _content):
                                    if (';' in _content):
                                        _content = re_amp.sub('&amp;', _content)
                                    else:
                                        _content = _content.replace('&', '&amp;')
                                if ('<' in _content):
                                    _content = _content.replace('<', '&lt;')
                                if ('>' in _content):
                                    _content = _content.replace('>', '&gt;')
                                if ('\x00' in _content):
                                    _content = _content.replace('\x00', '&#34;')
            if (_content is not None):
                append(_content)
        if (_backup_default_36811120 is _marker):
            del econtext['default']
        else:
            econtext['default'] = _backup_default_36811120
    else:
        _slot_body_footer(stream, econtext.copy(), econtext)
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</div>')
    if (_backup_attrs_36812632 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36812632
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</body>')
    if (_backup_attrs_36813640 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_36813640
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</html>')
    if (_backup_attrs_39812776 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39812776
    if (_backup_content_36741456 is _marker):
        del econtext['content']
    else:
        econtext['content'] = _backup_content_36741456

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    render_main(stream, econtext.copy(), rcontext)
    econtext.update(rcontext)
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
pass


# -*- coding: utf-8 -*-
pass
from chameleon.utils import Placeholder as _Placeholder
import sys as _sys
pass
_static_39102032 = {}
_static_39102544 = {}
_static_37140880 = {}
_static_39103376 = {}
_static_37139664 = {}
_static_37139600 = {}
_marker_default = _Placeholder()
import re
import functools
_marker = object()
g_re_amp = re.compile('&(?!([A-Za-z]+|#[0-9]+);)')
g_re_needs_escape = re.compile('[&<>\\"\\\']').search
re_whitespace = functools.partial(re.compile('\\s+').sub, ' ')

def render(stream, econtext, rcontext):
    append = stream.append
    getitem = econtext.__getitem__
    get = econtext.get
    _i18n_domain = None
    re_amp = g_re_amp
    re_needs_escape = g_re_needs_escape
    decode = getitem('decode')
    convert = getitem('convert')
    translate = getitem('translate')
    _backup_attrs_39095400 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x236b4d0> name=None at 236b310> -> _value
    _value = _static_37139664
    econtext['attrs'] = _value

    # <html ... (1:0)
    # --------------------------------------------------------
    append(u'<html>')
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_39815792 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x236b990> name=None at 236b890> -> _value
    _value = _static_37140880
    econtext['attrs'] = _value

    # <body ... (2:2)
    # --------------------------------------------------------
    append(u'<body>')
    _content_139955154988272 = u'\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_attrs_39828080 = get('attrs', _marker)

    # <Static value=<_ast.Dict object at 0x236b490> name=None at 236b390> -> _value
    _value = _static_37139600
    econtext['attrs'] = _value

    # <ul ... (3:4)
    # --------------------------------------------------------
    append(u'<ul>')
    _content_139955154988272 = u'\n      '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_i_35883472 = get('i', _marker)

    # <Expression u'(1, 2, 3)' (4:26)> -> _iterator
    try:
        _iterator = (1, 2, 3, )
    except:
        rcontext.setdefault('__error__', []).append((u'(1, 2, 3)', 4, 26, '<string>', _sys.exc_info()[1], ))
        raise

    (_iterator, __index_39101968, ) = getitem('repeat')(u'i', _iterator)
    econtext['i'] = None
    for _item in _iterator:
        econtext['i'] = _item
        _backup_attrs_40288912 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x254a650> name=None at 254a190> -> _value
        _value = _static_39102032
        econtext['attrs'] = _value

        # <li ... (4:37)
        # --------------------------------------------------------
        append(u'<li>')
        _backup_default_39802640 = get('default', _marker)

        # <Marker name='default' at 254a510> -> _value
        _value = _marker_default
        econtext['default'] = _value

        # <Expression u'i' (4:54)> -> _cache_39101904
        try:
            _cache_39101904 = getitem('i')
        except:
            rcontext.setdefault('__error__', []).append((u'i', 4, 54, '<string>', _sys.exc_info()[1], ))
            raise


        # <Identity expression=<Expression u'i' (4:54)> value=<Marker name='default' at 254a110> at 254a2d0> -> _condition
        _expression = _cache_39101904

        # <Marker name='default' at 254a110> -> _value
        _value = _marker_default
        _condition = (_expression is _value)
        if _condition:
            pass
        else:
            _content = _cache_39101904
            if (_content is None):
                pass
            else:
                if (_content is False):
                    _content = None
                else:
                    _tt = type(_content)
                    if ((_tt is int) or (_tt is float) or (_tt is long)):
                        _content = unicode(_content)
                    else:
                        try:
                            if (_tt is str):
                                _content = decode(_content)
                            else:
                                if (_tt is not unicode):
                                    try:
                                        _content = _content.__html__
                                    except:
                                        _content = convert(_content)
                                    else:
                                        raise RuntimeError
                        except RuntimeError:
                            _content = _content()
                        else:
                            if ((_content is not None) and (re_needs_escape(_content) is not None)):
                                if ('&' in _content):
                                    if (';' in _content):
                                        _content = re_amp.sub('&amp;', _content)
                                    else:
                                        _content = _content.replace('&', '&amp;')
                                if ('<' in _content):
                                    _content = _content.replace('<', '&lt;')
                                if ('>' in _content):
                                    _content = _content.replace('>', '&gt;')
                                if ('\x00' in _content):
                                    _content = _content.replace('\x00', '&#34;')
            if (_content is not None):
                append(_content)
        if (_backup_default_39802640 is _marker):
            del econtext['default']
        else:
            econtext['default'] = _backup_default_39802640
        append(u'</li>')
        if (_backup_attrs_40288912 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_40288912
        __index_39101968 -= 1
        if (__index_39101968 > 0):
            append('\n      ')
    if (_backup_i_35883472 is _marker):
        del econtext['i']
    else:
        econtext['i'] = _backup_i_35883472
    _content_139955154988272 = u'\n      '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_j_37194704 = get('j', _marker)

    # <Expression u'(1, 2, 3)' (5:42)> -> _iterator
    try:
        _iterator = (1, 2, 3, )
    except:
        rcontext.setdefault('__error__', []).append((u'(1, 2, 3)', 5, 42, '<string>', _sys.exc_info()[1], ))
        raise

    (_iterator, __index_39100944, ) = getitem('repeat')(u'j', _iterator)
    econtext['j'] = None
    for _item in _iterator:
        econtext['j'] = _item
        _backup_attrs_40302712 = get('attrs', _marker)

        # <Static value=<_ast.Dict object at 0x254ab90> name=None at 254af90> -> _value
        _value = _static_39103376
        econtext['attrs'] = _value

        # <li ... (5:53)
        # --------------------------------------------------------
        append(u'<li>')
        _backup_default_40289920 = get('default', _marker)

        # <Marker name='default' at 254a890> -> _value
        _value = _marker_default
        econtext['default'] = _value

        # <Expression u'j' (5:70)> -> _cache_39103632
        try:
            _cache_39103632 = getitem('j')
        except:
            rcontext.setdefault('__error__', []).append((u'j', 5, 70, '<string>', _sys.exc_info()[1], ))
            raise


        # <Identity expression=<Expression u'j' (5:70)> value=<Marker name='default' at 254aa90> at 254a390> -> _condition
        _expression = _cache_39103632

        # <Marker name='default' at 254aa90> -> _value
        _value = _marker_default
        _condition = (_expression is _value)
        if _condition:
            pass
        else:
            _content = _cache_39103632
            if (_content is None):
                pass
            else:
                if (_content is False):
                    _content = None
                else:
                    _tt = type(_content)
                    if ((_tt is int) or (_tt is float) or (_tt is long)):
                        _content = unicode(_content)
                    else:
                        try:
                            if (_tt is str):
                                _content = decode(_content)
                            else:
                                if (_tt is not unicode):
                                    try:
                                        _content = _content.__html__
                                    except:
                                        _content = convert(_content)
                                    else:
                                        raise RuntimeError
                        except RuntimeError:
                            _content = _content()
                        else:
                            if ((_content is not None) and (re_needs_escape(_content) is not None)):
                                if ('&' in _content):
                                    if (';' in _content):
                                        _content = re_amp.sub('&amp;', _content)
                                    else:
                                        _content = _content.replace('&', '&amp;')
                                if ('<' in _content):
                                    _content = _content.replace('<', '&lt;')
                                if ('>' in _content):
                                    _content = _content.replace('>', '&gt;')
                                if ('\x00' in _content):
                                    _content = _content.replace('\x00', '&#34;')
            if (_content is not None):
                append(_content)
        if (_backup_default_40289920 is _marker):
            del econtext['default']
        else:
            econtext['default'] = _backup_default_40289920
        append(u'</li>')
        if (_backup_attrs_40302712 is _marker):
            del econtext['attrs']
        else:
            econtext['attrs'] = _backup_attrs_40302712
        __index_39100944 -= 1
        if (__index_39100944 > 0):
            append('\n      ')
    if (_backup_j_37194704 is _marker):
        del econtext['j']
    else:
        econtext['j'] = _backup_j_37194704
    _content_139955154988272 = u'\n      '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _content_139955154988272 = u'\n        '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _backup_count_37019152 = get('count', _marker)

    # <Expression u'(1, 2, 3)' (7:38)> -> _iterator
    try:
        _iterator = (1, 2, 3, )
    except:
        rcontext.setdefault('__error__', []).append((u'(1, 2, 3)', 7, 38, '<string>', _sys.exc_info()[1], ))
        raise

    (_iterator, __index_39104016, ) = getitem('repeat')(u'count', _iterator)
    econtext['count'] = None
    for _item in _iterator:
        econtext['count'] = _item
        _content_139955154988272 = u'\n          '
        if (_content_139955154988272 is not None):
            append(_content_139955154988272)
        _backup_default_39927960 = get('default', _marker)

        # <Marker name='default' at 251bf10> -> _value
        _value = _marker_default
        econtext['default'] = _value

        # <Expression u'count' (8:29)> -> _cache_38911312
        try:
            _cache_38911312 = getitem('count')
        except:
            rcontext.setdefault('__error__', []).append((u'count', 8, 29, '<string>', _sys.exc_info()[1], ))
            raise


        # <Identity expression=<Expression u'count' (8:29)> value=<Marker name='default' at 251bc10> at 251bc90> -> _condition
        _expression = _cache_38911312

        # <Marker name='default' at 251bc10> -> _value
        _value = _marker_default
        _condition = (_expression is _value)
        if _condition:
            _backup_attrs_39930912 = get('attrs', _marker)

            # <Static value=<_ast.Dict object at 0x254a850> name=None at 254ae90> -> _value
            _value = _static_39102544
            econtext['attrs'] = _value

            # <span ... (8:10)
            # --------------------------------------------------------
            append(u'<span\n                />')
            if (_backup_attrs_39930912 is _marker):
                del econtext['attrs']
            else:
                econtext['attrs'] = _backup_attrs_39930912
        else:
            _content = _cache_38911312
            if (_content is None):
                pass
            else:
                if (_content is False):
                    _content = None
                else:
                    _tt = type(_content)
                    if ((_tt is int) or (_tt is float) or (_tt is long)):
                        _content = unicode(_content)
                    else:
                        try:
                            if (_tt is str):
                                _content = decode(_content)
                            else:
                                if (_tt is not unicode):
                                    try:
                                        _content = _content.__html__
                                    except:
                                        _content = convert(_content)
                                    else:
                                        raise RuntimeError
                        except RuntimeError:
                            _content = _content()
                        else:
                            if ((_content is not None) and (re_needs_escape(_content) is not None)):
                                if ('&' in _content):
                                    if (';' in _content):
                                        _content = re_amp.sub('&amp;', _content)
                                    else:
                                        _content = _content.replace('&', '&amp;')
                                if ('<' in _content):
                                    _content = _content.replace('<', '&lt;')
                                if ('>' in _content):
                                    _content = _content.replace('>', '&gt;')
                                if ('\x00' in _content):
                                    _content = _content.replace('\x00', '&#34;')
            if (_content is not None):
                append(_content)
        if (_backup_default_39927960 is _marker):
            del econtext['default']
        else:
            econtext['default'] = _backup_default_39927960

        # <Expression u"not repeat['count'].end" (9:40)> -> _condition
        try:
            _condition = not getitem('repeat')['count'].end
        except:
            rcontext.setdefault('__error__', []).append((u"not repeat['count'].end", 9, 40, '<string>', _sys.exc_info()[1], ))
            raise

        if _condition:
            _content_139955154988272 = u','
            if (_content_139955154988272 is not None):
                append(_content_139955154988272)
        _content_139955154988272 = u'\n       '
        if (_content_139955154988272 is not None):
            append(_content_139955154988272)
        __index_39104016 -= 1
        if (__index_39104016 > 0):
            append('\n        ')
    if (_backup_count_37019152 is _marker):
        del econtext['count']
    else:
        econtext['count'] = _backup_count_37019152
    _content_139955154988272 = u'\n      '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    _content_139955154988272 = u'.\n    '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</ul>')
    if (_backup_attrs_39828080 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39828080
    _content_139955154988272 = u'\n  '
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</body>')
    if (_backup_attrs_39815792 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39815792
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
    append(u'</html>')
    if (_backup_attrs_39095400 is _marker):
        del econtext['attrs']
    else:
        econtext['attrs'] = _backup_attrs_39095400
    _content_139955154988272 = u'\n'
    if (_content_139955154988272 is not None):
        append(_content_139955154988272)
pass